==> impact-0.0.3.tar.gz: lib/0_Impact_Global/2_Shared_Preference.dart <==
import 'dart:async';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';


var ImpactSelectedTheme,ImpactSelectedLang,ImpactPageSelectorLoaded,ImpactSelectedCountry,ImpactSelectedCountryCode;
var ImpactUserID,ImpactUserName,ImpactUserProfilePic,ImpactUserPhone,ImpactUserEmail,ImpactUserPass;
bool ImpactIsDebugging = true;
TextDirection ImpactTxtDirection = TextDirection.ltr;
Future<SharedPreferences> _prefs = SharedPreferences.getInstance();
var ImpactPrimaryColor,ImpactSecondaryColor;
var ImpactScreenWidth,ImpactScreenHeight;
var ImpactPlatform,ImpactLang;

var ImpactLightPrimaryColor    = Colors.blue;
var ImpactLightSecondaryColor  = Colors.blueGrey;
var ImpactDarkPrimaryColor     = Colors.black87;
var ImpactDarkSecondaryColor   = Colors.black54;

PrintUserData() {
  print("ImpactSelectedTheme          ------> $ImpactSelectedTheme");
  print("ImpactSelectedVariable       ------> $ImpactSelectedLang");
  print("ImpactPageSelectorLoaded     ------> $ImpactPageSelectorLoaded");
  print("ImpactUserName               ------> $ImpactUserName");
  print("ImpactUserProfilePic         ------> $ImpactUserProfilePic");
  print("ImpactUserPhone              ------> $ImpactUserPhone");
  print("ImpactUserEmail              ------> $ImpactUserEmail");
  print("ImpactUserPass               ------> $ImpactUserPass");
  print("ImpactUserID                 ------> $ImpactUserID");
  print("ImpactSelectedCountry        ------> $ImpactSelectedCountry");
  print("ImpactSelectedCountryCode    ------> $ImpactSelectedCountryCode");
  print("ImpactPlatform                ------> $ImpactPlatform");
}


Future<void> SP_Save(Variable,Value,Name) async {
  final SharedPreferences prefs = await _prefs;
  Variable = prefs.getString(Name);
  prefs.setString(Name,Value).then((bool success) {
    return Variable;
  });
}


SP_Get(Variable,Name) async {
  SharedPreferences prefs = await SharedPreferences.getInstance();
  Variable = (prefs.getString(Name) ?? '');
  return Variable;
}


ImpactSaveAndGetAllInfo() async {

  await SP_Save(ImpactSelectedTheme,ImpactSelectedTheme.toString(),'ImpactSelectedTheme');
  ImpactSelectedTheme = await SP_Get(ImpactSelectedTheme.toString(),'ImpactSelectedTheme');

  await SP_Save(ImpactSelectedLang,ImpactSelectedLang.toString(),'ImpactSelectedLang');
  ImpactSelectedLang = await SP_Get(ImpactSelectedLang.toString(),'ImpactSelectedLang');

  await SP_Save(ImpactPageSelectorLoaded,ImpactPageSelectorLoaded.toString(),'ImpactPageSelectorLoaded');
  ImpactPageSelectorLoaded = await SP_Get(ImpactPageSelectorLoaded.toString(),'ImpactPageSelectorLoaded');

  await SP_Save(ImpactUserID,ImpactUserID.toString(),'ImpactUserID');
  ImpactUserID = await SP_Get(ImpactUserID.toString(),'ImpactUserID');

  await SP_Save(ImpactUserName,ImpactUserName.toString(),'ImpactUserName');
  ImpactUserName = await SP_Get(ImpactUserName.toString(),'ImpactUserName');

  await SP_Save(ImpactUserProfilePic,ImpactUserProfilePic.toString(),'ImpactUserProfilePic');
  ImpactUserProfilePic = await SP_Get(ImpactUserProfilePic.toString(),'ImpactUserProfilePic');

  await SP_Save(ImpactUserPhone,ImpactUserPhone.toString(),'ImpactUserPhone');
  ImpactUserPhone = await SP_Get(ImpactUserPhone.toString(),'ImpactUserPhone');

  await SP_Save(ImpactUserEmail,ImpactUserEmail.toString(),'ImpactUserEmail');
  ImpactUserEmail = await SP_Get(ImpactUserEmail.toString(),'ImpactUserEmail');

  await SP_Save(ImpactUserPass,ImpactUserPass.toString(),'ImpactUserPass');
  ImpactUserPass = await SP_Get(ImpactUserPass.toString(),'ImpactUserPass');

  await SP_Save(ImpactSelectedCountryCode,ImpactSelectedCountryCode.toString(),'ImpactSelectedCountryCode');
  ImpactSelectedCountryCode = await SP_Get(ImpactSelectedCountryCode.toString(),'ImpactSelectedCountryCode');

  await SP_Save(ImpactSelectedCountry,ImpactSelectedCountry.toString(),'ImpactSelectedCountry');
  ImpactSelectedCountry = await SP_Get(ImpactSelectedCountry.toString(),'ImpactSelectedCountry');


  if(ImpactIsDebugging){
    PrintUserData();
  }

}

==> impact-0.0.4.tar.gz: lib/0_Impact_Global/2_Shared_Preference.dart <==
import 'dart:async';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';


var ImpactSelectedTheme,ImpactSelectedLang,ImpactPageSelectorLoaded,ImpactSelectedCountry,ImpactSelectedCountryCode;
var ImpactUserID,ImpactUserName,ImpactUserProfilePic,ImpactUserPhone,ImpactUserEmail,ImpactUserPass;
bool ImpactIsDebugging = true;
TextDirection ImpactTxtDirection = TextDirection.ltr;
Future<SharedPreferences> _prefs = SharedPreferences.getInstance();
var ImpactPrimaryColor,ImpactSecondaryColor;
var ImpactScreenWidth,ImpactScreenHeight;
var ImpactPlatform,ImpactLang,ImpactUserLocation;

var ImpactLightPrimaryColor    = Colors.blue;
var ImpactLightSecondaryColor  = Colors.blueGrey;
var ImpactDarkPrimaryColor     = Colors.black87;
var ImpactDarkSecondaryColor   = Colors.black54;

PrintUserData() {
  print("ImpactSelectedTheme          ------> $ImpactSelectedTheme");
  print("ImpactSelectedVariable       ------> $ImpactSelectedLang");
  print("ImpactPageSelectorLoaded     ------> $ImpactPageSelectorLoaded");
  print("ImpactUserName               ------> $ImpactUserName");
  print("ImpactUserProfilePic         ------> $ImpactUserProfilePic");
  print("ImpactUserPhone              ------> $ImpactUserPhone");
  print("ImpactUserEmail              ------> $ImpactUserEmail");
  print("ImpactUserPass               ------> $ImpactUserPass");
  print("ImpactUserID                 ------> $ImpactUserID");
  print("ImpactSelectedCountry        ------> $ImpactSelectedCountry");
  print("ImpactSelectedCountryCode    ------> $ImpactSelectedCountryCode");
  print("ImpactPlatform               ------> $ImpactPlatform");
  print("ImpactUserLocation           ------> $ImpactUserLocation");
}


Future<void> SP_Save(Variable,Value,Name) async {
  final SharedPreferences prefs = await _prefs;
  Variable = prefs.getString(Name);
  prefs.setString(Name,Value).then((bool success) {
    return Variable;
  });
}


SP_Get(Variable,Name) async {
  SharedPreferences prefs = await SharedPreferences.getInstance();
  Variable = (prefs.getString(Name) ?? '');
  return Variable;
}


ImpactSaveAndGetAllInfo() async {

  await SP_Save(ImpactSelectedTheme,ImpactSelectedTheme.toString(),'ImpactSelectedTheme');
  ImpactSelectedTheme = await SP_Get(ImpactSelectedTheme.toString(),'ImpactSelectedTheme');

  await SP_Save(ImpactSelectedLang,ImpactSelectedLang.toString(),'ImpactSelectedLang');
  ImpactSelectedLang = await SP_Get(ImpactSelectedLang.toString(),'ImpactSelectedLang');

  await SP_Save(ImpactPageSelectorLoaded,ImpactPageSelectorLoaded.toString(),'ImpactPageSelectorLoaded');
  ImpactPageSelectorLoaded = await SP_Get(ImpactPageSelectorLoaded.toString(),'ImpactPageSelectorLoaded');

  await SP_Save(ImpactUserID,ImpactUserID.toString(),'ImpactUserID');
  ImpactUserID = await SP_Get(ImpactUserID.toString(),'ImpactUserID');

  await SP_Save(ImpactUserName,ImpactUserName.toString(),'ImpactUserName');
  ImpactUserName = await SP_Get(ImpactUserName.toString(),'ImpactUserName');

  await SP_Save(ImpactUserProfilePic,ImpactUserProfilePic.toString(),'ImpactUserProfilePic');
  ImpactUserProfilePic = await SP_Get(ImpactUserProfilePic.toString(),'ImpactUserProfilePic');

  await SP_Save(ImpactUserPhone,ImpactUserPhone.toString(),'ImpactUserPhone');
  ImpactUserPhone = await SP_Get(ImpactUserPhone.toString(),'ImpactUserPhone');

  await SP_Save(ImpactUserEmail,ImpactUserEmail.toString(),'ImpactUserEmail');
  ImpactUserEmail = await SP_Get(ImpactUserEmail.toString(),'ImpactUserEmail');

  await SP_Save(ImpactUserPass,ImpactUserPass.toString(),'ImpactUserPass');
  ImpactUserPass = await SP_Get(ImpactUserPass.toString(),'ImpactUserPass');

  await SP_Save(ImpactSelectedCountryCode,ImpactSelectedCountryCode.toString(),'ImpactSelectedCountryCode');
  ImpactSelectedCountryCode = await SP_Get(ImpactSelectedCountryCode.toString(),'ImpactSelectedCountryCode');

  await SP_Save(ImpactSelectedCountry,ImpactSelectedCountry.toString(),'ImpactSelectedCountry');
  ImpactSelectedCountry = await SP_Get(ImpactSelectedCountry.toString(),'ImpactSelectedCountry');

  await SP_Save(ImpactUserLocation,ImpactUserLocation.toString(),'ImpactUserLocation');
  ImpactUserLocation = await SP_Get(ImpactUserLocation.toString(),'ImpactUserLocation');

  if(ImpactIsDebugging){
    PrintUserData();
  }

}
